@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -15,18 +15,19 @@ BEGIN {
 		},
 		scope => sub {
 			my ($caller, $self, %props) = @_;
-			for (keys %{$props{properties}}) {
-				$props{properties}->{$_} = {%{$props{properties}{$_}}};
-				if ($props{properties}{$_}{value} && ref $props{properties}{$_}{value} eq 'CODE') {
-					my $cb = $props{properties}{$_}{value};
-					$props{properties}{$_}{value} = sub { $cb->($META{initialised}{${$self}->{identifier}}, @_) };
+			for my $prop (keys %{$props{properties}}) {
+				$props{properties}->{$prop} = {%{$props{properties}{$prop}}};
+				if ($props{properties}{$prop}{value} && ref $props{properties}{$prop}{value} eq 'CODE') {
+					my $cb = $props{properties}{$prop}{value};
+					$props{properties}{$prop}{value} = sub { $cb->($META{initialised}{${$self}->{identifier}}, @_) };
 				}
-				my $trigger = $props{properties}{$_}{trigger};
-				if (defined $trigger) {
-					$props{properties}{$_}{trigger} = sub { 
-						$trigger->($META{initialised}{${$self}->{identifier}}, @_) 
-
-					};
+				for (qw/trigger delete_trigger/) {
+					my $trigger = $props{properties}{$prop}{$_};
+					if (defined $trigger) {
+						$props{properties}{$prop}{$_} = sub { 
+							$trigger->($META{initialised}{${$self}->{identifier}}, @_) 
+						};
+					}
 				}
 			}
 			return \%props;
@@ -42,7 +43,7 @@ BEGIN {
 		set_prop => sub {
 			my ($caller, $prop, %options) = @_;
 			if ($META{$caller}{properties}{$prop}) {
-				defined $options{$_} && do { $META{$caller}{properties}{$prop}{$_} = $options{$_} } for qw/builder trigger/;
+				defined $options{$_} && do { $META{$caller}{properties}{$prop}{$_} = $options{$_} } for qw/builder trigger delete_trigger/;
 				if ($META{$caller}{properties}{$prop}{writeable}) {
 					$META{$caller}{properties}{$prop}{value} = $options{value} if exists $options{value};
 					$META{$caller}{properties}{$prop}{class} = $caller;
@@ -95,7 +96,7 @@ BEGIN {
 					my ($prop, $options) = (shift @properties, shift @properties);
 
 					my $ref = ref $options;					
-					if (!$ref || $ref ne 'HASH' || ! grep { defined $options->{$_} } qw/initable writeable builder enumerable configurable trigger value/) {
+					if (!$ref || $ref ne 'HASH' || ! grep { defined $options->{$_} } qw/initable writeable builder enumerable configurable trigger delete_trigger value/) {
 						$options = {
 							initable => 1,
 							enumerable => 1,
@@ -356,7 +357,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
@@ -387,6 +388,7 @@ Version 0.13
 				$self->{bend_update_count}++;
 				return $value;
 			}
+			delete_trigger => sub { ... }
 		},
 		...
 	);
@@ -449,7 +451,9 @@ The buidler property/key expects either a code ref or a scalar that represents t
 
 The trigger property/key expects a code ref that expects the value for that property to be returned so it can also be used for coecion on setting of a property. Two values are passed into a trigger the first being $self which allows you to access and manipulate the existing objects other properties, the second is the value that is being set for the property being called.
 
-A trigger is also called on DELETE, in this case you will get three params, the second being the text 'DELETE', the third being the last set value.
+=head2 delete_trigger
+
+A delete trigger works the same as a trigger but is called on delete instead of set. The second param is the last set value for that property.
 
 =head2 index
 
@@ -601,7 +605,7 @@ Along with class definitions you can also generate object using Rope itself, the
 
 =head2 destroy
 
-For objects that are running in a long process, like under a web server, you will want to explicitly call destroy on your objects as to achieve the correcting scoping a reference has to be held in memory. If running under a script the problem will not exists as destruction happens when that script ends.
+For objects that are running in a long process, like under a web server, you will want to explicitly call destroy on your objects as to achieve the correct scoping a reference has to be held in memory. If running under a script the problem will not exists as destruction happens when that script ends.
 
 	$knot->destroy();
 
