@@ -122,8 +122,8 @@ sub EXISTS {
  
 sub DELETE { 
         my $k = $_[0]->{properties}->{$_[1]};
-	if ($k->{trigger}) {
-		$k->{trigger}->('DELETE', $k->{value});
+	if ($k->{delete_trigger}) {
+		$k->{delete_trigger}->($k->{value});
 	}
 	my $del = !$_[0]->{locked} && $k->{writeable} ? delete $_[0]->{properties}->{$_[1]} : undef;
 	$_[0]->compile() if $del;
